@@ -6,7 +6,7 @@
 ;; Maintainer: Protesilaos Stavrou General Issues <~protesilaos/general-issues@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/spacious-padding
 ;; Mailing-List: https://lists.sr.ht/~protesilaos/general-issues
-;; Version: 0.2.1
+;; Version: 0.2.2
 ;; Package-Requires: ((emacs "28.1"))
 ;; Keywords: convenience, focus, writing, presentation
 
@@ -115,7 +115,7 @@ Return 4 if KEY does not have a value."
     (spacious-padding--get-box-width :header-line-width))
    ((memq face spacious-padding--tab-faces)
     (spacious-padding--get-box-width :tab-width))
-   (t (error "`%s' is not relevant to `spacious-padding-mode'" face)))))
+   (t (error "`%s' is not relevant to `spacious-padding-mode'" face))))
 
 (defun spacious-padding-set-face-box-padding (face fallback)
   "Return appropriate face attributes for FACE with FALLBACK face background."
@@ -124,7 +124,7 @@ Return 4 if KEY does not have a value."
           (list
            :line-width (spacious-padding--get-face-width face)
            :color (face-background face nil fallback)
-           :style nil)))
+           :style nil))))
 
 (defun spacious-padding-set-invisible-dividers (_theme)
   "Make window dividers for THEME invisible."
